@@ -105,6 +105,12 @@ by diminishing returns in model deviance.""",
         """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor. If you set weight = 0 for a row, the returned prediction frame at that row is zero and this is incorrect. To get an accurate prediction, remove all rows with weight == 0.""",
         H2OTypeConverters.toNullableString())
 
+    maxCategoricalLevels = Param(
+        Params._dummy(),
+        "maxCategoricalLevels",
+        """For every categorical feature, only use this many most frequent categorical levels for model training. Only used for categorical_encoding == EnumLimited.""",
+        H2OTypeConverters.toInt())
+
     aucType = Param(
         Params._dummy(),
         "aucType",
@@ -153,6 +159,9 @@ by diminishing returns in model deviance.""",
     def getWeightCol(self):
         return self.getOrDefault(self.weightCol)
 
+    def getMaxCategoricalLevels(self):
+        return self.getOrDefault(self.maxCategoricalLevels)
+
     def getAucType(self):
         return self.getOrDefault(self.aucType)
 
@@ -198,5 +207,8 @@ by diminishing returns in model deviance.""",
     def setWeightCol(self, value):
         return self._set(weightCol=value)
 
+    def setMaxCategoricalLevels(self, value):
+        return self._set(maxCategoricalLevels=value)
+
     def setAucType(self, value):
         return self._set(aucType=value)
